# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [1.0.1] (2020-05-12)

### Added
- Check the vt's preference value for type 'file'. [#130](https://github.com/greenbone/ospd-openvas/pull/130).
- Check for malformed credentials. [#160](https://github.com/greenbone/ospd-openvas/pull/160).
- Send messages generated by the scannner main process. [#171](https://github.com/greenbone/ospd-openvas/pull/171).
- Add missing scan preferences expand_vhosts and test_empty_vhost. [#185](https://github.com/greenbone/ospd-openvas/pull/185)
- Use lock file during feed update to avoid corrupted cache. [#206](https://github.com/greenbone/ospd-openvas/pull/206)
- Check if cache is available before update. [#241](https://github.com/greenbone/ospd-openvas/pull/241)

### Changed
- Less strict checks for the nvti cache version.
  [#151](https://github.com/greenbone/ospd-openvas/pull/151)
  [#167](https://github.com/greenbone/ospd-openvas/pull/167)
- Exit with exit code 1 if it was not possible to connect to redis. [#133](https://github.com/greenbone/ospd-openvas/pull/133)
- Return None if the scan finished successfully. [#137](https://github.com/greenbone/ospd-openvas/pull/137)
- Use a generator to yield the VTs directly from redis and reduce data in cache.[#203](https://github.com/greenbone/ospd-openvas/pull/203)
- Activate initialized flag during the feed update.[#240](https://github.com/greenbone/ospd-openvas/pull/240)

### Fixed
- Improve redis clean out when stopping a scan. [#128](https://github.com/greenbone/ospd-openvas/pull/128)
- Improve error handling when creating vts xml elements. [#139](https://github.com/greenbone/ospd-openvas/pull/139)
- Init the superclass with kwargs. [#141](https://github.com/greenbone/ospd-openvas/pull/141)
- Avoid ospd-openvas to crash if redis is flushed during vt dictionary creation. [#146](https://github.com/greenbone/ospd-openvas/pull/146)
- Check for a valid OID when prepare results. [#183](https://github.com/greenbone/ospd-openvas/pull/183)
- Fix snmp credentials. [#187](https://github.com/greenbone/ospd-openvas/pull/187)
- Escape script name before adding the result in an xml entity. [#189](https://github.com/greenbone/ospd-openvas/pull/189)

### Removed
- Remove use_mac_addr, vhost_ip and vhost scan preferences. [#185](https://github.com/greenbone/ospd-openvas/pull/185)

[1.0.1]: https://github.com/greenbone/ospd-openvas/compare/v1.0.1...v1.0.0

## [1.0.0] (2019-10-11)

This is the first release of the ospd-openvas module for the Greenbone
Vulnerability Management (GVM) framework.

[1.0.0]: https://github.com/greenbone/ospd-openvas/commits/v1.0.0
